==> libreoffice-l10n_4.2.8.orig.tar.xz: libreoffice-4.2.8/salhelper/source/dynload.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <salhelper/dynload.hxx>
#include <rtl/ustrbuf.hxx>

namespace salhelper
{

typedef void*   (SAL_CALL *ApiInitFunction) (void);

ORealDynamicLoader::ORealDynamicLoader(ORealDynamicLoader ** ppSetToZeroInDestructor_,
                       const rtl::OUString& moduleName,
                       const rtl::OUString& initFunction,
                       void* pApi,
                       oslModule pModule)
    : m_pApi(pApi)
    , m_refCount(1)
    , m_pModule(pModule)
    , m_strModuleName(moduleName)
    , m_strInitFunction(initFunction)
    , ppSetToZeroInDestructor( ppSetToZeroInDestructor_ )
{
}

ORealDynamicLoader* ORealDynamicLoader::newInstance(ORealDynamicLoader ** ppSetToZeroInDestructor,
                                  const rtl::OUString& moduleName,
                                  const rtl::OUString& initFunction)
{
#ifdef DISABLE_DYNLOADING
    (void) ppSetToZeroInDestructor;
    (void) moduleName;
    (void) initFunction;

    return NULL;
#else
    ApiInitFunction initFunc;
    oslModule pModule = osl_loadModule(moduleName.pData, SAL_LOADMODULE_DEFAULT);

    if ( !pModule )
    {
        return NULL;
    }

    initFunc = (ApiInitFunction)osl_getFunctionSymbol(
        pModule, initFunction.pData);

    if ( !initFunc )
    {
        osl_unloadModule(pModule);
        return NULL;
    }

    return(new ORealDynamicLoader(ppSetToZeroInDestructor, moduleName,
                                 initFunction,
                                 initFunc(),
                                 pModule));
#endif
}

ORealDynamicLoader::~ORealDynamicLoader()
{
    // set the address to zero
    if( ppSetToZeroInDestructor )
        *ppSetToZeroInDestructor = 0;

    if (m_pModule)
    {
#ifndef DISABLE_DYNLOADING
        osl_unloadModule(m_pModule);
#endif
        m_pModule = NULL;
    }
}

sal_uInt32 ORealDynamicLoader::acquire()
{
    return ++m_refCount;
}

sal_uInt32 ORealDynamicLoader::release()
{
    sal_uInt32 nRet = --m_refCount;
    if( nRet == 0 )
        delete this;
    return nRet;
}


void* ORealDynamicLoader::getApi() const
{
    return m_pApi;
}

} // namespace salhelper

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-l10n_5.0.2.orig.tar.xz: libreoffice-5.0.2/salhelper/source/dynload.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <salhelper/dynload.hxx>
#include <rtl/ustrbuf.hxx>

namespace salhelper
{

typedef void*   (SAL_CALL *ApiInitFunction) (void);

ORealDynamicLoader::ORealDynamicLoader(ORealDynamicLoader ** ppSetToZeroInDestructor_,
                       const rtl::OUString& moduleName,
                       const rtl::OUString& initFunction,
                       void* pApi,
                       oslModule pModule)
    : m_pApi(pApi)
    , m_refCount(1)
    , m_pModule(pModule)
    , m_strModuleName(moduleName)
    , m_strInitFunction(initFunction)
    , ppSetToZeroInDestructor( ppSetToZeroInDestructor_ )
{
}

ORealDynamicLoader* ORealDynamicLoader::newInstance(ORealDynamicLoader ** ppSetToZeroInDestructor,
                                  const rtl::OUString& moduleName,
                                  const rtl::OUString& initFunction)
{
#ifdef DISABLE_DYNLOADING
    (void) ppSetToZeroInDestructor;
    (void) moduleName;
    (void) initFunction;

    return NULL;
#else
    ApiInitFunction initFunc;
    oslModule pModule = osl_loadModule(moduleName.pData, SAL_LOADMODULE_DEFAULT);

    if ( !pModule )
    {
        return NULL;
    }

    initFunc = reinterpret_cast<ApiInitFunction>(osl_getFunctionSymbol(
        pModule, initFunction.pData));

    if ( !initFunc )
    {
        osl_unloadModule(pModule);
        return NULL;
    }

    return(new ORealDynamicLoader(ppSetToZeroInDestructor, moduleName,
                                 initFunction,
                                 initFunc(),
                                 pModule));
#endif
}

ORealDynamicLoader::~ORealDynamicLoader()
{
    // set the address to zero
    if( ppSetToZeroInDestructor )
        *ppSetToZeroInDestructor = 0;

    if (m_pModule)
    {
#ifndef DISABLE_DYNLOADING
        osl_unloadModule(m_pModule);
#endif
        m_pModule = NULL;
    }
}

sal_uInt32 ORealDynamicLoader::acquire()
{
    return ++m_refCount;
}

sal_uInt32 ORealDynamicLoader::release()
{
    sal_uInt32 nRet = --m_refCount;
    if( nRet == 0 )
        delete this;
    return nRet;
}


void* ORealDynamicLoader::getApi() const
{
    return m_pApi;
}

} // namespace salhelper

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
